@@ -11,8 +11,8 @@
 #define KIO_JOBUIDELEGATEEXTENSION_H
 
 #include "kiocore_export.h"
-#include <kio/global.h>
 #include <QDateTime>
+#include <kio/global.h>
 
 class KJob;
 namespace KIO
@@ -28,11 +28,13 @@ enum RenameDialog_Option {
     RenameDialog_Overwrite = 1, ///< We have an existing destination, show details about it and offer to overwrite it.
     RenameDialog_OverwriteItself = 2, ///< Warn that the current operation would overwrite a file with itself, which is not allowed.
     RenameDialog_Skip = 4, ///< Offer a "Skip" button, to skip other files too. Requires RenameDialog_MultipleItems.
-    RenameDialog_MultipleItems = 8, ///< Set if the current operation concerns multiple files, so it makes sense to offer buttons that apply the user's choice to all files/folders.
+    RenameDialog_MultipleItems =
+        8, ///< Set if the current operation concerns multiple files, so it makes sense to offer buttons that apply the user's choice to all files/folders.
     RenameDialog_Resume = 16, ///< Offer a "Resume" button (plus "Resume All" if RenameDialog_MultipleItems).
     RenameDialog_NoRename = 64, ///< Don't offer a "Rename" button.
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 78)
-    RenameDialog_IsDirectory = 128, ///< @deprecated since 5.78, use RenameDialog_DestIsDirectory instead.
+    RenameDialog_IsDirectory KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 78, "Use RenameDialog_DestIsDirectory.") =
+        128, ///< @deprecated since 5.78, use RenameDialog_DestIsDirectory instead.
 #endif
     RenameDialog_DestIsDirectory = 128, ///< @since 5.78. The destination is a directory, the dialog updates labels and tooltips accordingly.
     RenameDialog_SourceIsDirectory = 256, ///< @since 5.78. The source is a directory, the dialog updates labels and tooltips accordingly.
@@ -49,13 +51,13 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(RenameDialog_Options)
  * @deprecated since 5.0, use the RenameDialog_Option enum values
  */
 enum {
-    M_OVERWRITE = RenameDialog_Overwrite,
-    M_OVERWRITE_ITSELF = RenameDialog_OverwriteItself,
-    M_SKIP = RenameDialog_Skip,
-    M_MULTI = RenameDialog_MultipleItems,
-    M_RESUME = RenameDialog_Resume,
-    M_NORENAME = RenameDialog_NoRename,
-    M_ISDIR = RenameDialog_IsDirectory
+    M_OVERWRITE KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use RenameDialog_Overwrite.") = RenameDialog_Overwrite,
+    M_OVERWRITE_ITSELF KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use RenameDialog_OverwriteItself.") = RenameDialog_OverwriteItself,
+    M_SKIP KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use RenameDialog_Skip.") = RenameDialog_Skip,
+    M_MULTI KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use RenameDialog_MultipleItems.") = RenameDialog_MultipleItems,
+    M_RESUME KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use RenameDialog_Resume.") = RenameDialog_Resume,
+    M_NORENAME KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use RenameDialog_NoRename.") = RenameDialog_NoRename,
+    M_ISDIR KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use RenameDialog_IsDirectory.") = RenameDialog_IsDirectory,
 };
 /**
  * @deprecated since 5.0, use RenameDialog_Options
@@ -65,13 +67,27 @@ typedef RenameDialog_Options RenameDialog_Mode;
 #endif
 
 /**
- * SkipDialog_MultipleItems: Set if the current operation concerns multiple files, so it makes sense
- *  to offer buttons that apply the user's choice to all files/folders.
  * @see SkipDialog_Options
  * @since 5.0
  */
 enum SkipDialog_Option {
-    SkipDialog_MultipleItems = 8
+    /**
+     * Set if the current operation concerns multiple files, so it makes sense
+     * to offer buttons that apply the user's choice to all files/folders.
+     */
+    SkipDialog_MultipleItems = 8,
+    /**
+     * Set if the current operation involves copying files/folders with certain
+     * characters in their names that are not supported by the destination
+     * filesystem (e.g. VFAT and NTFS disallow "*" in file/folder names).
+     *
+     * This will make the SkipDialog show a "Replace" button that can be used
+     * to instruct the underlying job to replace any problematic character with
+     * an underscore "_".
+     *
+     * @since 5.86
+     */
+    SkipDialog_Replace_Invalid_Chars = 16,
 };
 /**
  * Stores a combination of #SkipDialog_Option values.
@@ -79,7 +95,6 @@ enum SkipDialog_Option {
 Q_DECLARE_FLAGS(SkipDialog_Options, SkipDialog_Option)
 Q_DECLARE_OPERATORS_FOR_FLAGS(SkipDialog_Options)
 
-
 /**
  * The result of a rename or skip dialog
  */
@@ -94,30 +109,47 @@ enum RenameDialog_Result {
     Result_ResumeAll = 7,
     Result_AutoRename = 8,
     Result_Retry = 9,
-    /*
+    /**
      * Can be returned only when multiple files are passed, Option overwrite is passed
      * And files modification times are valid
      * @since 5.77
      */
     Result_OverwriteWhenOlder = 10,
+    /**
+     * Can be returned if the user selects to replace any character disallowed
+     * by the destination filesystem with an underscore "_".
+     *
+     * See @ref SkipDialog_Option::SkipDialog_Replace_Invalid_Chars
+     *
+     * @since 5.86
+     */
+    Result_ReplaceInvalidChars = 11,
+    /**
+     * The same as @c Result_ReplaceInvalidChars, but the user selected to
+     * automatically replace any invalid character, without being asked about
+     * every file/folder.
+     *
+     * @since 5.86
+     */
+    Result_ReplaceAllInvalidChars = 12,
 
-    // @deprecated since 5.0, use the undeprecated enum values
+// @deprecated since 5.0, use the undeprecated enum values
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
-    R_CANCEL = Result_Cancel,
-    R_RENAME = Result_Rename,
-    R_SKIP = Result_Skip,
-    R_AUTO_SKIP = Result_AutoSkip,
-    R_OVERWRITE = Result_Overwrite,
-    R_OVERWRITE_ALL = Result_OverwriteAll,
-    R_RESUME = Result_Resume,
-    R_RESUME_ALL = Result_ResumeAll,
-    R_AUTO_RENAME = Result_AutoRename,
-    R_RETRY = Result_Retry,
+    R_CANCEL KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Cancel.") = Result_Cancel,
+    R_RENAME KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Rename.") = Result_Rename,
+    R_SKIP KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Skip.") = Result_Skip,
+    R_AUTO_SKIP KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_AutoSkip.") = Result_AutoSkip,
+    R_OVERWRITE KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Overwrite.") = Result_Overwrite,
+    R_OVERWRITE_ALL KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_OverwriteAll.") = Result_OverwriteAll,
+    R_RESUME KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Resume.") = Result_Resume,
+    R_RESUME_ALL KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_ResumeAll.") = Result_ResumeAll,
+    R_AUTO_RENAME KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_AutoRename.") = Result_AutoRename,
+    R_RETRY KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Retry.") = Result_Retry,
 
-    S_CANCEL = Result_Cancel,
-    S_SKIP = Result_Skip,
-    S_AUTO_SKIP = Result_AutoSkip,
-    S_RETRY = Result_Retry
+    S_CANCEL KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Cancel.") = Result_Cancel,
+    S_SKIP KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Skip.") = Result_Skip,
+    S_AUTO_SKIP KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_AutoSkip.") = Result_AutoSkip,
+    S_RETRY KIOCORE_ENUMERATOR_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "Use Result_Retry.") = Result_Retry,
 #endif
 };
 typedef RenameDialog_Result SkipDialog_Result;
@@ -146,7 +178,6 @@ protected:
     virtual ~JobUiDelegateExtension();
 
 public:
-
     /**
      * \relates KIO::RenameDialog
      * Construct a modal, parent-less "rename" dialog, and return
@@ -167,25 +198,23 @@ public:
      * @return the result
      */
     virtual KIO::RenameDialog_Result askFileRename(KJob *job,
-            const QString &caption,
-            const QUrl &src,
-            const QUrl &dest,
-            KIO::RenameDialog_Options options,
-            QString &newDest,
-            KIO::filesize_t sizeSrc = KIO::filesize_t(-1),
-            KIO::filesize_t sizeDest = KIO::filesize_t(-1),
-            const QDateTime &ctimeSrc = QDateTime(),
-            const QDateTime &ctimeDest = QDateTime(),
-            const QDateTime &mtimeSrc = QDateTime(),
-            const QDateTime &mtimeDest = QDateTime()) = 0;
+                                                   const QString &caption,
+                                                   const QUrl &src,
+                                                   const QUrl &dest,
+                                                   KIO::RenameDialog_Options options,
+                                                   QString &newDest,
+                                                   KIO::filesize_t sizeSrc = KIO::filesize_t(-1),
+                                                   KIO::filesize_t sizeDest = KIO::filesize_t(-1),
+                                                   const QDateTime &ctimeSrc = QDateTime(),
+                                                   const QDateTime &ctimeDest = QDateTime(),
+                                                   const QDateTime &mtimeSrc = QDateTime(),
+                                                   const QDateTime &mtimeDest = QDateTime()) = 0;
 
     /**
      * @internal
      * See skipdialog.h
      */
-    virtual KIO::SkipDialog_Result askSkip(KJob *job,
-                                      KIO::SkipDialog_Options options,
-                                      const QString &error_text) = 0;
+    virtual KIO::SkipDialog_Result askSkip(KJob *job, KIO::SkipDialog_Options options, const QString &error_text) = 0;
 
     /**
      * The type of deletion: real deletion, moving the files to the trash
@@ -212,8 +241,7 @@ public:
      * Note: the window passed to setWindow is used as the parent for the message box.
      * @return true if confirmed
      */
-    virtual bool askDeleteConfirmation(const QList<QUrl> &urls, DeletionType deletionType,
-                                       ConfirmationType confirmationType) = 0;
+    virtual bool askDeleteConfirmation(const QList<QUrl> &urls, DeletionType deletionType, ConfirmationType confirmationType) = 0;
 
     /**
      * Message box types.
@@ -229,7 +257,7 @@ public:
         WarningYesNoCancel = 4,
         Information = 5,
         SSLMessageBox = 6,
-        //In KMessageBox::DialogType; Sorry = 7, Error = 8, QuestionYesNoCancel = 9
+        // In KMessageBox::DialogType; Sorry = 7, Error = 8, QuestionYesNoCancel = 9
         WarningContinueCancelDetailed = 10,
     };
 
@@ -246,7 +274,8 @@ public:
      * @param dontAskAgainName the name used to store result from 'Do not ask again' checkbox.
      * @param sslMetaData SSL information used by the SSLMessageBox.
      */
-    virtual int requestMessageBox(MessageBoxType type, const QString &text,
+    virtual int requestMessageBox(MessageBoxType type,
+                                  const QString &text,
                                   const QString &caption,
                                   const QString &buttonYes,
                                   const QString &buttonNo,
@@ -258,7 +287,7 @@ public:
     enum ClipboardUpdaterMode {
         UpdateContent,
         OverwriteContent,
-        RemoveContent
+        RemoveContent,
     };
 
     /**
