@@ -1,27 +1,15 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2012 Dawit Alemayehu <adawit@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2012 Dawit Alemayehu <adawit@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "usernotificationhandler_p.h"
 
-#include "slave.h"
 #include "job_p.h"
-
-#include <QDebug>
+#include "kiocoredebug.h"
+#include "slave.h"
 
 #include <QTimer>
 
@@ -59,7 +47,7 @@ void UserNotificationHandler::requestMessageBox(SlaveInterface *iface, int type,
 
     m_pendingRequests.append(r);
     if (m_pendingRequests.count() == 1) {
-        QTimer::singleShot(0, this, SLOT(processRequest()));
+        QTimer::singleShot(0, this, &UserNotificationHandler::processRequest);
     }
 }
 
@@ -78,11 +66,13 @@ void UserNotificationHandler::processRequest()
         if (m_cachedResults.contains(key)) {
             result = *(m_cachedResults[key]);
         } else {
-            JobUiDelegateExtension *delegateExtension = 0;
-            if (r->slave->job())
+            JobUiDelegateExtension *delegateExtension = nullptr;
+            if (r->slave->job()) {
                 delegateExtension = SimpleJobPrivate::get(r->slave->job())->m_uiDelegateExtension;
-            if (!delegateExtension)
+            }
+            if (!delegateExtension) {
                 delegateExtension = KIO::defaultJobUiDelegateExtension();
+            }
             if (delegateExtension) {
                 const JobUiDelegateExtension::MessageBoxType type = static_cast<JobUiDelegateExtension::MessageBoxType>(r->type);
                 result = delegateExtension->requestMessageBox(type,
@@ -98,7 +88,7 @@ void UserNotificationHandler::processRequest()
             m_cachedResults.insert(key, new int(result));
         }
     } else {
-        qWarning() << "Cannot prompt user because the requesting ioslave died!" << r->slave;
+        qCWarning(KIO_CORE) << "Cannot prompt user because the requesting ioslave died!" << r->slave;
     }
 
     r->slave->sendMessageBoxAnswer(result);
@@ -108,6 +98,6 @@ void UserNotificationHandler::processRequest()
     if (m_pendingRequests.isEmpty()) {
         m_cachedResults.clear();
     } else {
-        QTimer::singleShot(0, this, SLOT(processRequest()));
+        QTimer::singleShot(0, this, &UserNotificationHandler::processRequest);
     }
 }
