@@ -9,27 +9,32 @@
 #ifndef KDIROPERATOR_H_
 #define KDIROPERATOR_H_
 
-#include <QWidget>
-#include <QStack>
-#include <QStyleOptionViewItem>
-
-#include <KToggleAction>
-#include <KCompletion>
-#include <kdirlister.h>
-#include <kfileitem.h>
-#include <kfile.h>
 #include "kiofilewidgets_export.h"
+#include <kfile.h>
+
+#include <QStyleOptionViewItem>
+#include <QUrl>
+#include <QWidget>
 
 class QAbstractItemView;
+class QMenu;
 class QModelIndex;
 class QProgressBar;
 
 class KActionCollection;
 class KActionMenu;
 class KConfigGroup;
-class KDirLister;
-class KPreviewWidgetBase;
+class KFileItemList;
 class KFilePreviewGenerator;
+class KPreviewWidgetBase;
+
+#include <KToggleAction> // SIC TODO KF6: Not used, remove
+#include <QStack> // SIC TODO KF6: Not used, remove
+
+// SIC TODO KF6: forward-declaration is enough for these three
+#include <KCompletion>
+#include <KDirLister>
+#include <KFileItem>
 
 namespace KIO
 {
@@ -68,14 +73,10 @@ class KDirOperatorPrivate;
  * \code
  *   KDirOperator *op = new KDirOperator(QUrl("file:///home/gis"), this);
  *   // some signals you might be interested in
- *   connect(op, SIGNAL(urlEntered(const QUrl&)),
- *           SLOT(urlEntered(const QUrl&)));
- *   connect(op, SIGNAL(fileHighlighted(const KFileItem &)),
- *           SLOT(fileHighlighted(const KFileItem &)));
- *   connect(op, SIGNAL(fileSelected(const KFileItem &)),
- *           SLOT(fileSelected(const KFileItem &)));
- *   connect(op, SIGNAL(finishedLoading()),
- *           SLOT(slotLoadingFinished()));
+ *   connect(op, &KDirOperator::urlEntered, this, [this](const QUrl &url) { slotUrlEntered(url); });
+ *   connect(op, &KDirOperator::fileHighlighted, this, [this](const KFileItem &item) { slotFileHighlighted(item) });
+ *   connect(op, &KDirOperator::fileSelected, this, [this](const KFileItem &item) { slotFileSelected(item) });
+ *   connect(op, &KDirOperator::finishedLoading, this, [this]() { slotLoadingFinished(); };
  *
  *   KConfigGroup grp(KSharedConfig::openConfig(),"Your KDiroperator ConfigGroup" );
  *   op->readConfig( &grp);
@@ -99,11 +100,11 @@ public:
      * The various action types. These values can be or'd together
      */
     enum ActionType {
-        SortActions =  1,
-        ViewActions =  2,
-        NavActions  =  4,
-        FileActions =  8,
-        AllActions  = 15
+        SortActions = 1,
+        ViewActions = 2,
+        NavActions = 4,
+        FileActions = 8,
+        AllActions = 15,
     };
 
     /**
@@ -113,8 +114,7 @@ public:
      *
      * This constructor doesn't start loading the url, setView will do it.
      */
-    explicit KDirOperator(const QUrl &urlName  = QUrl(),
-                          QWidget *parent = nullptr);
+    explicit KDirOperator(const QUrl &urlName = QUrl{}, QWidget *parent = nullptr);
     /**
      * Destroys the KDirOperator.
      */
@@ -494,7 +494,7 @@ public:
     void setFollowNewDirectories(bool enable);
 
     /**
-     * @returns true if setUrl is called on newly created directories, false 
+     * @returns true if setUrl is called on newly created directories, false
      * otherwise. Enabled by default.
      * @since 5.62
      * @see setFollowNewDirectories
@@ -524,8 +524,10 @@ public:
      * to the user.
      * @returns true if the directory could be created.
      */
-    KIOFILEWIDGETS_DEPRECATED_VERSION(5, 78, "Deprecated for lack of usage; use the other"
-                                             " KDirOperator::mkdir() method instead.")
+    KIOFILEWIDGETS_DEPRECATED_VERSION(5,
+                                      78,
+                                      "Deprecated for lack of usage; use the other"
+                                      " KDirOperator::mkdir() method instead.")
     virtual bool mkdir(const QString &directory, bool enterDirectory = true);
 #endif
 
@@ -537,8 +539,7 @@ public:
      * @param ask specifies whether a confirmation dialog should be shown
      * @param showProgress passed to the DeleteJob to show a progress dialog
      */
-    virtual KIO::DeleteJob *del(const KFileItemList &items, QWidget *parent = nullptr,
-                                bool ask = true, bool showProgress = true);
+    virtual KIO::DeleteJob *del(const KFileItemList &items, QWidget *parent = nullptr, bool ask = true, bool showProgress = true);
 
     /**
      * Clears the forward and backward history.
@@ -603,13 +604,12 @@ public:
      * @param ask specifies whether a confirmation dialog should be shown
      * @param showProgress passed to the CopyJob to show a progress dialog
      */
-    virtual KIO::CopyJob *trash(const KFileItemList &items, QWidget *parent,
-                                bool ask = true, bool showProgress = true);
+    virtual KIO::CopyJob *trash(const KFileItemList &items, QWidget *parent, bool ask = true, bool showProgress = true);
 
     /**
-      * Returns the preview generator for the current view.
-      * @since 4.2
-      */
+     * Returns the preview generator for the current view.
+     * @since 4.2
+     */
     KFilePreviewGenerator *previewGenerator() const;
 
     /**
@@ -682,6 +682,16 @@ public:
      */
     QStringList supportedSchemes() const;
 
+    /**
+     * Call with @c true to add open-with actions to items in the view.
+     * This can be useful when you're attaching an image or text file to
+     * an email or uploading an image to some online service, and need to
+     * check the contents before going forward.
+     *
+     * @since 5.87
+     */
+    void showOpenWithActions(bool enable);
+
 protected:
     /**
      * A view factory for creating predefined fileviews. Called internally by setView,
