@@ -10,17 +10,16 @@
 #include <QLayout>
 #include <QMimeDatabase>
 
-#include <QDebug>
-#include <kio/previewjob.h>
-#include <KPluginLoader>
 #include <KPluginFactory>
+#include <QDebug>
 #include <kimagefilepreview.h>
+#include <kio/previewjob.h>
 
 bool KFileMetaPreview::s_tryAudioPreview = true;
 
 KFileMetaPreview::KFileMetaPreview(QWidget *parent)
-    : KPreviewWidgetBase(parent),
-      haveAudioPreview(false)
+    : KPreviewWidgetBase(parent)
+    , haveAudioPreview(false)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
@@ -28,7 +27,7 @@ KFileMetaPreview::KFileMetaPreview(QWidget *parent)
     layout->addWidget(m_stack);
 
     // ###
-//     m_previewProviders.setAutoDelete( true );
+    //     m_previewProviders.setAutoDelete( true );
     initPreviewProviders();
 }
 
@@ -44,14 +43,14 @@ void KFileMetaPreview::initPreviewProviders()
 
     // image previews
     KImageFilePreview *imagePreview = new KImageFilePreview(m_stack);
-    (void) m_stack->addWidget(imagePreview);
+    (void)m_stack->addWidget(imagePreview);
     m_stack->setCurrentWidget(imagePreview);
     resize(imagePreview->sizeHint());
 
     const QStringList mimeTypes = imagePreview->supportedMimeTypes();
     QStringList::ConstIterator it = mimeTypes.begin();
     for (; it != mimeTypes.end(); ++it) {
-//         qDebug(".... %s", (*it).toLatin1().constData());
+        //         qDebug(".... %s", (*it).toLatin1().constData());
         m_previewProviders.insert(*it, imagePreview);
     }
 }
@@ -64,7 +63,7 @@ KPreviewWidgetBase *KFileMetaPreview::findExistingProvider(const QString &mimeTy
     }
 
     if (mimeInfo.isValid()) {
-        // check mime type inheritance
+        // check MIME type inheritance
         const QStringList parentMimeTypes = mimeInfo.allAncestors();
         for (const QString &parentMimeType : parentMimeTypes) {
             provider = m_previewProviders.value(parentMimeType);
@@ -74,7 +73,7 @@ KPreviewWidgetBase *KFileMetaPreview::findExistingProvider(const QString &mimeTy
         }
     }
 
-    // ### mimetype may be image/* for example, try that
+    // ### MIME type may be image/* for example, try that
     const int index = mimeType.indexOf(QLatin1Char('/'));
     if (index > 0) {
         provider = m_previewProviders.value(mimeType.leftRef(index + 1) + QLatin1Char('*'));
@@ -103,20 +102,18 @@ KPreviewWidgetBase *KFileMetaPreview::previewProviderFor(const QString &mimeType
         return provider;
     }
 
-//qDebug("#### didn't find anything for: %s", mimeType.toLatin1().constData());
+    // qDebug("#### didn't find anything for: %s", mimeType.toLatin1().constData());
 
-    if (s_tryAudioPreview &&
-            !mimeType.startsWith(QLatin1String("text/")) &&
-            !mimeType.startsWith(QLatin1String("image/"))) {
+    if (s_tryAudioPreview && !mimeType.startsWith(QLatin1String("text/")) && !mimeType.startsWith(QLatin1String("image/"))) {
         if (!haveAudioPreview) {
             KPreviewWidgetBase *audioPreview = createAudioPreview(m_stack);
             if (audioPreview) {
                 haveAudioPreview = true;
-                (void) m_stack->addWidget(audioPreview);
+                (void)m_stack->addWidget(audioPreview);
                 const QStringList mimeTypes = audioPreview->supportedMimeTypes();
                 QStringList::ConstIterator it = mimeTypes.begin();
                 for (; it != mimeTypes.end(); ++it) {
-                    // only add non already handled mimetypes
+                    // only add non already handled MIME types
                     if (m_previewProviders.constFind(*it) == m_previewProviders.constEnd()) {
                         m_previewProviders.insert(*it, audioPreview);
                     }
@@ -125,7 +122,7 @@ KPreviewWidgetBase *KFileMetaPreview::previewProviderFor(const QString &mimeType
         }
     }
 
-    // with the new mimetypes from the audio-preview, try again
+    // with the new MIME types from the audio-preview, try again
     provider = findExistingProvider(mimeType, mimeInfo);
     if (provider) {
         return provider;
@@ -163,18 +160,15 @@ void KFileMetaPreview::clearPreview()
     }
 }
 
-void KFileMetaPreview::addPreviewProvider(const QString &mimeType,
-        KPreviewWidgetBase *provider)
+void KFileMetaPreview::addPreviewProvider(const QString &mimeType, KPreviewWidgetBase *provider)
 {
     m_previewProviders.insert(mimeType, provider);
 }
 
 void KFileMetaPreview::clearPreviewProviders()
 {
-    QHash<QString, KPreviewWidgetBase *>::const_iterator i = m_previewProviders.constBegin();
-    while (i != m_previewProviders.constEnd()) {
-        m_stack->removeWidget(i.value());
-        ++i;
+    for (auto it = m_previewProviders.cbegin(); it != m_previewProviders.cend(); ++it) {
+        m_stack->removeWidget(it.value());
     }
     qDeleteAll(m_previewProviders);
     m_previewProviders.clear();
@@ -183,16 +177,12 @@ void KFileMetaPreview::clearPreviewProviders()
 // static
 KPreviewWidgetBase *KFileMetaPreview::createAudioPreview(QWidget *parent)
 {
-    KPluginLoader loader(QStringLiteral("kfileaudiopreview"));
-    KPluginFactory *factory = loader.factory();
-    if (!factory) {
-        qWarning() << "Couldn't load kfileaudiopreview" << loader.errorString();
+    KPluginMetaData data(QStringLiteral("kfileaudiopreview"));
+    if (auto plugin = KPluginFactory::instantiatePlugin<KPreviewWidgetBase>(data, parent).plugin) {
+        plugin->setObjectName(QStringLiteral("kfileaudiopreview"));
+        return plugin;
+    } else {
         s_tryAudioPreview = false;
         return nullptr;
     }
-    KPreviewWidgetBase *w = factory->create<KPreviewWidgetBase>(parent);
-    if (w) {
-        w->setObjectName(QStringLiteral("kfileaudiopreview"));
-    }
-    return w;
 }
