@@ -39,6 +39,8 @@
 #include <QTimer>
 #include <QUrlQuery>
 
+#include <algorithm>
+
 using namespace KDEPrivate;
 
 struct LocationData {
@@ -146,9 +148,9 @@ public:
 
     /**
      * Returns true, if the MIME type of the path represents a
-     * compressed file like TAR or ZIP.
+     * compressed file like TAR or ZIP, as listed in @p archiveMimetypes
      */
-    bool isCompressedPath(const QUrl &path) const;
+    bool isCompressedPath(const QUrl &path, const QStringList &archiveMimetypes) const;
 
     void removeTrailingSlash(QString &url) const;
 
@@ -180,6 +182,11 @@ public:
     bool m_showPlacesSelector = false;
     bool m_showFullPath = false;
     int m_historyIndex = 0;
+
+    struct {
+        bool showHidden = false;
+        bool sortHiddenLast = false;
+    } m_subfolderOptions;
 };
 
 KUrlNavigatorPrivate::KUrlNavigatorPrivate(KUrlNavigator *qq, KFilePlacesModel *placesModel)
@@ -229,7 +236,7 @@ KUrlNavigatorPrivate::KUrlNavigatorPrivate(KUrlNavigator *qq, KFilePlacesModel *
     m_pathBox->setAutoDeleteCompletionObject(true);
 
     // TODO KF6: remove this QOverload, only KUrlComboBox::returnPressed(const QString &) will remain
-    q->connect(m_pathBox, QOverload<const QString &>::of(&KUrlComboBox::returnPressed), q, [this]() {
+    q->connect(m_pathBox, qOverload<const QString &>(&KUrlComboBox::returnPressed), q, [this]() {
         slotReturnPressed();
     });
     q->connect(m_pathBox, &KUrlComboBox::urlActivated, q, &KUrlNavigator::setLocationUrl);
@@ -477,7 +484,7 @@ void KUrlNavigatorPrivate::openContextMenu(const QPoint &p)
     // We are checking for receivers because it's odd to have a tab entry even
     // if it's not supported, like in the case of the open dialog
     if (q->receivers(SIGNAL(tabRequested(QUrl))) > 0) {
-        for (auto button : qAsConst(m_navButtons)) {
+        for (auto button : std::as_const(m_navButtons)) {
             if (button->geometry().contains(p)) {
                 const auto url = button->url();
                 QAction *openInTab = popup->addAction(QIcon::fromTheme(QStringLiteral("tab-new")), i18n("Open %1 in tab", button->text()));
@@ -693,7 +700,7 @@ void KUrlNavigatorPrivate::updateButtonVisibility()
 
     // Check whether buttons must be hidden at all...
     int requiredButtonWidth = 0;
-    for (const KUrlNavigatorButton *button : qAsConst(m_navButtons)) {
+    for (const KUrlNavigatorButton *button : std::as_const(m_navButtons)) {
         requiredButtonWidth += button->minimumWidth();
     }
 
@@ -705,15 +712,11 @@ void KUrlNavigatorPrivate::updateButtonVisibility()
     }
 
     // Hide buttons...
-    QList<KUrlNavigatorButton *>::const_iterator it = m_navButtons.constEnd();
-    const QList<KUrlNavigatorButton *>::const_iterator itBegin = m_navButtons.constBegin();
     bool isLastButton = true;
     bool hasHiddenButtons = false;
-
     QList<KUrlNavigatorButton *> buttonsToShow;
-    while (it != itBegin) {
-        --it;
-        KUrlNavigatorButton *button = (*it);
+    for (auto it = m_navButtons.crbegin(); it != m_navButtons.crend(); ++it) {
+        KUrlNavigatorButton *button = *it;
         availableWidth -= button->minimumWidth();
         if ((availableWidth <= 0) && !isLastButton) {
             button->hide();
@@ -731,7 +734,7 @@ void KUrlNavigatorPrivate::updateButtonVisibility()
 
     // All buttons have the correct activation state and
     // can be shown now
-    for (KUrlNavigatorButton *button : qAsConst(buttonsToShow)) {
+    for (KUrlNavigatorButton *button : std::as_const(buttonsToShow)) {
         button->show();
     }
 
@@ -822,7 +825,7 @@ void KUrlNavigatorPrivate::switchToBreadcrumbMode()
 
 void KUrlNavigatorPrivate::deleteButtons()
 {
-    for (KUrlNavigatorButton *button : qAsConst(m_navButtons)) {
+    for (KUrlNavigatorButton *button : std::as_const(m_navButtons)) {
         button->hide();
         button->deleteLater();
     }
@@ -836,32 +839,13 @@ QUrl KUrlNavigatorPrivate::retrievePlaceUrl() const
     return currentUrl;
 }
 
-bool KUrlNavigatorPrivate::isCompressedPath(const QUrl &url) const
+bool KUrlNavigatorPrivate::isCompressedPath(const QUrl &url, const QStringList &archiveMimetypes) const
 {
     QMimeDatabase db;
     const QMimeType mime = db.mimeTypeForUrl(QUrl(url.toString(QUrl::StripTrailingSlash)));
-    // Note: this list of MIME types depends on the protocols implemented by kio_archive and krarc
-    /* clang-format off */
-    return mime.inherits(QStringLiteral("application/x-compressed-tar"))
-        || mime.inherits(QStringLiteral("application/x-bzip-compressed-tar"))
-        || mime.inherits(QStringLiteral("application/x-lzma-compressed-tar"))
-        || mime.inherits(QStringLiteral("application/x-xz-compressed-tar"))
-        || mime.inherits(QStringLiteral("application/x-tar"))
-        || mime.inherits(QStringLiteral("application/x-tarz"))
-        || mime.inherits(QStringLiteral("application/x-tzo"))
-        // (not sure KTar supports those?)
-        || mime.inherits(QStringLiteral("application/zip"))
-        || mime.inherits(QStringLiteral("application/x-archive"))
-        || mime.inherits(QStringLiteral("application/x-7z-compressed"))
-        // the following depends on krarc
-        || mime.inherits(QStringLiteral("application/x-rpm"))
-        || mime.inherits(QStringLiteral("application/x-source-rpm"))
-        || mime.inherits(QStringLiteral("application/vnd.rar"))
-        || mime.inherits(QStringLiteral("application/x-ace"))
-        || mime.inherits(QStringLiteral("application/x-arj"))
-        || mime.inherits(QStringLiteral("application/x-cpio"))
-        || mime.inherits(QStringLiteral("application/x-lha"));
-    /* clang-format on */
+    return std::any_of(archiveMimetypes.begin(), archiveMimetypes.end(), [mime](const QString &archiveType) {
+        return mime.inherits(archiveType);
+    });
 }
 
 void KUrlNavigatorPrivate::removeTrailingSlash(QString &url) const
@@ -1023,7 +1007,7 @@ void KUrlNavigator::setActive(bool active)
         d->m_active = active;
 
         d->m_dropDownButton->setActive(active);
-        for (KUrlNavigatorButton *button : qAsConst(d->m_navButtons)) {
+        for (KUrlNavigatorButton *button : std::as_const(d->m_navButtons)) {
             button->setActive(active);
         }
 
@@ -1083,33 +1067,33 @@ void KUrlNavigator::setLocationUrl(const QUrl &newUrl)
     // code locationUrl() and url become the same URLs
     QUrl firstChildUrl = KIO::UrlUtil::firstChildUrl(locationUrl(), url);
 
-    /* clang-format off */
-    if (url.scheme() == QLatin1String("tar")
-        || url.scheme() == QLatin1String("zip")
-        || url.scheme() == QLatin1String("sevenz")
-        || url.scheme() == QLatin1String("krarc")) {
-        /* clang-format on */
-        // The URL represents a tar-, zip- or 7z-file, or an archive file supported by krarc.
-        // Check whether the URL is really part of the archive file, otherwise
-        // replace it by the local path again.
-        bool insideCompressedPath = d->isCompressedPath(url);
-        if (!insideCompressedPath) {
-            QUrl prevUrl = url;
-            QUrl parentUrl = KIO::upUrl(url);
-            while (parentUrl != prevUrl) {
-                if (d->isCompressedPath(parentUrl)) {
-                    insideCompressedPath = true;
-                    break;
+    const QString scheme = url.scheme();
+    if (!scheme.isEmpty()) {
+        // Check if the URL represents a tar-, zip- or 7z-file, or an archive file supported by krarc.
+        const QStringList archiveMimetypes = KProtocolInfo::archiveMimetypes(scheme);
+
+        if (!archiveMimetypes.isEmpty()) {
+            // Check whether the URL is really part of the archive file, otherwise
+            // replace it by the local path again.
+            bool insideCompressedPath = d->isCompressedPath(url, archiveMimetypes);
+            if (!insideCompressedPath) {
+                QUrl prevUrl = url;
+                QUrl parentUrl = KIO::upUrl(url);
+                while (parentUrl != prevUrl) {
+                    if (d->isCompressedPath(parentUrl, archiveMimetypes)) {
+                        insideCompressedPath = true;
+                        break;
+                    }
+                    prevUrl = parentUrl;
+                    parentUrl = KIO::upUrl(parentUrl);
                 }
-                prevUrl = parentUrl;
-                parentUrl = KIO::upUrl(parentUrl);
             }
-        }
-        if (!insideCompressedPath) {
-            // drop the tar:, zip:, sevenz: or krarc: protocol since we are not
-            // inside the compressed path
-            url.setScheme(QStringLiteral("file"));
-            firstChildUrl.setScheme(QStringLiteral("file"));
+            if (!insideCompressedPath) {
+                // drop the tar:, zip:, sevenz: or krarc: protocol since we are not
+                // inside the compressed path
+                url.setScheme(QStringLiteral("file"));
+                firstChildUrl.setScheme(QStringLiteral("file"));
+            }
         }
     }
 
@@ -1263,13 +1247,13 @@ bool KUrlNavigator::eventFilter(QObject *watched, QEvent *event)
             requestActivation();
             setFocus();
         }
-        for (KUrlNavigatorButton *button : qAsConst(d->m_navButtons)) {
+        for (KUrlNavigatorButton *button : std::as_const(d->m_navButtons)) {
             button->setShowMnemonic(true);
         }
         break;
 
     case QEvent::FocusOut:
-        for (KUrlNavigatorButton *button : qAsConst(d->m_navButtons)) {
+        for (KUrlNavigatorButton *button : std::as_const(d->m_navButtons)) {
             button->setShowMnemonic(false);
         }
         break;
@@ -1312,6 +1296,26 @@ QWidget *KUrlNavigator::dropWidget() const
     return d->m_dropWidget;
 }
 
+void KUrlNavigator::setShowHiddenFolders(bool showHiddenFolders)
+{
+    d->m_subfolderOptions.showHidden = showHiddenFolders;
+}
+
+bool KUrlNavigator::showHiddenFolders() const
+{
+    return d->m_subfolderOptions.showHidden;
+}
+
+void KUrlNavigator::setSortHiddenFoldersLast(bool sortHiddenFoldersLast)
+{
+    d->m_subfolderOptions.sortHiddenLast = sortHiddenFoldersLast;
+}
+
+bool KUrlNavigator::sortHiddenFoldersLast() const
+{
+    return d->m_subfolderOptions.sortHiddenLast;
+}
+
 #if KIOFILEWIDGETS_BUILD_DEPRECATED_SINCE(4, 5)
 const QUrl &KUrlNavigator::url() const
 {
